PolicySource

Enum PolicySource 

pub enum PolicySource {
    EntityInline {
        entity_arn: String,
        entity_id: String,
        policy_name: String,
    },
    EntityAttachedPolicy {
        policy_arn: String,
        policy_id: String,
        version: String,
    },
    GroupInline {
        group_arn: String,
        group_id: String,
        policy_name: String,
    },
    GroupAttachedPolicy {
        group_arn: String,
        group_id: String,
        policy_arn: String,
        policy_id: String,
        version: String,
    },
    Resource {
        resource_arn: String,
        policy_name: Option<String>,
    },
    PermissionBoundary {
        policy_arn: String,
        policy_id: String,
        version: String,
    },
    OrgServiceControl {
        policy_arn: String,
        policy_name: String,
        applied_arn: String,
    },
    Session,
}
The source of a policy.

Variants



EntityInline

An inline policy directly attached to an IAM entity (user, role).

Fields

entity_arn: String

The ARN of the entity.

entity_id: String

The IAM ID of the entity.

policy_name: String

The name of the policy.



EntityAttachedPolicy

A managed policy that is attached to an IAM entity (user, role).

Fields

policy_arn: String

The ARN of the of the policy.

policy_id: String

The IAM ID of the policy.

version: String

The version of the policy used.



GroupInline

An inline policy directly attached to an IAM group that an IAM user ia a member of.

Fields

group_arn: String

The ARN of the IAM group.

group_id: String

The IAM ID of the group.

policy_name: String

The name of the policy.



GroupAttachedPolicy

A managed policy that is attached to an IAM group that an IAM user is a member of.

Fields

group_arn: String

The ARN of the of IAM group.

group_id: String

The IAM ID of the group.

policy_arn: String

The ARN of the of the policy.

policy_id: String

The IAM ID of the policy.

version: String

The version of the policy used.



Resource

A policy attached to a resource being accessed.

Fields

resource_arn: String

The ARN of the resource being accessed.

policy_name: Option<String>

The name of the policy, if any.



PermissionBoundary

A permissions boundary attached to an IAM entity (user, role).

Fields

policy_arn: String

The ARN of the the policy used as a permissions boundary.

policy_id: String

The IAM ID of the policy used as a permissions boundary.

version: String

The version of the policy used.



OrgServiceControl

An service control policy attached to an account or organizational unit.

Fields

policy_arn: String

The ARN of the the policy used as a service control policy.

policy_name: String

The name of the policy used as a service control policy.

applied_arn: String

The ARN of the account or organizational unit that the policy is attached to.



Session

A policy embedded in an assumed role session.

Implementations

Source

impl PolicySource

pub fn is_boundary(&self) -> bool

Indicates whether the policy is being used permissions boundary.

Permissions boundaries are used to limit the permissions in effect. Allow effects in a permissions boundary do not grant permissions, but must be combined with an allow effect in a non-permissions boundary policy to be effective. Absence of an allow effect in a permissions boundary is the same as a deny effect.

pub fn new_entity_inline<S1, S2, S3>( entity_arn: S1, entity_id: S2, policy_name: S3, ) -> Self
where S1: Into<String>, S2: Into<String>, S3: Into<String>,

Create a new PolicySource::EntityInline object.

pub fn new_entity_attached_policy<S1, S2, S3>( policy_arn: S1, policy_id: S2, version: S3, ) -> Self
where S1: Into<String>, S2: Into<String>, S3: Into<String>,

pub fn new_group_inline<S1, S2, S3>( group_arn: S1, group_id: S2, policy_name: S3, ) -> Self
where S1: Into<String>, S2: Into<String>, S3: Into<String>,

Create a new PolicySource::GroupInline object.

pub fn new_group_attached_policy<S1, S2, S3, S4, S5>( group_arn: S1, group_id: S2, policy_arn: S3, policy_id: S4, version: S5, ) -> Self
where S1: Into<String>, S2: Into<String>, S3: Into<String>, S4: Into<String>, S5: Into<String>,

Create a new PolicySource::GroupAttachedPolicy object.

pub fn new_resource<S1, S2>(resource_arn: S1, policy_name: Option<S2>) -> Self
where S1: Into<String>, S2: Into<String>,

Create a new PolicySource::Resource object.

pub fn new_permission_boundary<S1, S2, S3>( policy_arn: S1, policy_id: S2, version: S3, ) -> Self
where S1: Into<String>, S2: Into<String>, S3: Into<String>,

Create a new PolicySource::PermissionBoundary object.

pub fn new_org_service_control<S1, S2, S3>( policy_arn: S1, policy_name: S2, applied_arn: S3, ) -> Self
where S1: Into<String>, S2: Into<String>, S3: Into<String>,

Create a new PolicySource::OrgServiceControl object.

pub fn new_session() -> Self

Create a new PolicySource::Session object.